diff options
| author | KunoiSayami <[email protected]> | 2023-07-02 21:53:47 +0800 |
|---|---|---|
| committer | KunoiSayami <[email protected]> | 2023-07-02 21:53:47 +0800 |
| commit | c71e687de86691c0149804ef10721ac9c230ab9e (patch) | |
| tree | c5edef26ed08eeea4c4479016faea2dbcca7430c /expt_220830.cu | |
| parent | 0b09bc40d295e7b383f2e5c8ddba255f0ac680ca (diff) | |
refactor: Change basic function name
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_220830.cu')
| -rw-r--r-- | expt_220830.cu | 8 |
1 files changed, 4 insertions, 4 deletions
diff --git a/expt_220830.cu b/expt_220830.cu index fc05092..520e127 100644 --- a/expt_220830.cu +++ b/expt_220830.cu @@ -54,10 +54,10 @@ __global__ void kernel(unsigned long step, const double slice_size, auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i; // printf("%d\n", tid); - auto index = (int)(custom_sort.sample_cdf_custom_version( - cudaSampleItem, cudaPopulationItem[tid]) / - slice_size) - - 1; + auto index = + (int)(custom_sort.cdf(cudaSampleItem, cudaPopulationItem[tid]) / + slice_size) - + 1; // printf("%llu %d\n", cudaPopulationItem[tid], index); /*if (cdf_result[index]) { while (cdf_result[++index]) { |
